@@ -3,10 +3,12 @@
 Heavily Modified from RestForce 1.0.0
 """
 
-DEFAULT_CLIENT_ID_PREFIX = 'simple-salesforce'
+DEFAULT_CLIENT_ID_PREFIX = 'RestForce'
 
+
+import time
 import warnings
-from datetime import datetime, timedelta, timezone
+from datetime import datetime, timedelta
 from html import escape
 from json.decoder import JSONDecodeError
 
@@ -20,20 +22,18 @@ from .util import getUniqueElementValueFromXmlString
 
 # pylint: disable=invalid-name,too-many-arguments,too-many-locals
 def SalesforceLogin(
-        username=None,
-        password=None,
-        security_token=None,
-        organizationId=None,
-        sf_version=DEFAULT_API_VERSION,
-        proxies=None,
-        session=None,
-        client_id=None,
-        domain=None,
-        consumer_key=None,
-        consumer_secret=None,
-        privatekey_file=None,
-        privatekey=None,
-        ):
+    username=None,
+    password=None,
+    security_token=None,
+    organizationId=None,
+    sf_version=DEFAULT_API_VERSION,
+    proxies=None,
+    session=None,
+    client_id=None,
+    domain=None,
+    consumer_key=None,
+    privatekey_file=None,
+):
     """Return a tuple of `(session_id, sf_instance)` where `session_id` is the
     session ID to use for authentication to Salesforce and `sf_instance` is
     the domain of the instance of Salesforce to use for the session.
@@ -56,12 +56,9 @@ def SalesforceLogin(
                 common domains, such as 'login' or 'test', or
                 Salesforce My domain. If not used, will default to
                 'login'.
-    * consumer_key -- the consumer key generated for the user/app
-    * consumer_secret -- the consumer secret generated for the user/app
+    * consumer_key -- the consumer key generated for the user
     * privatekey_file -- the path to the private key file used
-                         for signing the JWT token.
-    * privatekey -- the private key to use
-                         for signing the JWT token.
+                         for signing the JWT token
     """
 
     if domain is None:
@@ -108,28 +105,6 @@ def SalesforceLogin(
             username=username, password=password, token=security_token,
             client_id=client_id)
 
-    elif username is not None and \
-            consumer_key is not None and \
-            consumer_secret is not None:
-        header = {'Content-Type': 'application/json'}
-        payload = {
-            'grant_type': 'password',
-            'client_id': consumer_key,
-            'client_secret': consumer_secret,
-            'username': username,
-            'password': password
-            }
-
-        login_token_request_data = {
-            'grant_type': 'password'
-            }
-
-        return token_login(
-            'https://{domain}.salesforce.com/services/oauth2/token'.format(
-                domain=domain),
-            payload, domain, consumer_key,
-            None, proxies, session)
-
     # Check if IP Filtering is used in conjunction with organizationId
     elif organizationId is not None:
         # IP Filtering Login Soap request body
@@ -177,29 +152,25 @@ def SalesforceLogin(
             username=username, password=password, client_id=client_id)
     elif username is not None and \
             consumer_key is not None and \
-            (privatekey_file is not None or privatekey is not None):
+            privatekey_file is not None:
         header = {'alg': 'RS256'}
-        expiration = datetime.now(timezone.utc) + timedelta(minutes=3)
+        expiration = datetime.utcnow() + timedelta(minutes=3)
         payload = {
             'iss': consumer_key,
             'sub': username,
             'aud': 'https://{domain}.salesforce.com'.format(domain=domain),
             'exp': '{exp:.0f}'.format(
-                exp=expiration.timestamp()
-                )
-            }
-        if privatekey_file is not None:
-            with open(privatekey_file, 'rb') as key_file:
-                key = key_file.read()
-        else:
-            key = privatekey
-
-        assertion = jwt.encode(header, payload, key)
+                exp=time.mktime(expiration.timetuple()) +
+                    expiration.microsecond / 1e6
+            )
+        }
+        with open(privatekey_file, 'rb') as key:
+            assertion = jwt.encode(header, payload, key.read())
 
         login_token_request_data = {
             'grant_type': 'urn:ietf:params:oauth:grant-type:jwt-bearer',
             'assertion': assertion
-            }
+        }
 
         return token_login(
             'https://{domain}.salesforce.com/services/oauth2/token'.format(
@@ -218,10 +189,10 @@ def SalesforceLogin(
         'content-type': 'text/xml',
         'charset': 'UTF-8',
         'SOAPAction': 'login'
-        }
+    }
 
     return soap_login(soap_url, login_soap_request_body,
-                      login_soap_request_headers, proxies, session)
+        login_soap_request_headers, proxies, session)
 
 
 def soap_login(soap_url, request_body, headers, proxies, session=None):
@@ -258,10 +229,10 @@ def token_login(token_url, token_data, domain, consumer_key,
 
     try:
         json_response = response.json()
-    except JSONDecodeError as exc:
+    except JSONDecodeError:
         raise SalesforceAuthenticationFailed(
             response.status_code, response.text
-            ) from exc
+        )
 
     if response.status_code != 200:
         except_code = json_response.get('error')
@@ -270,9 +241,9 @@ def token_login(token_url, token_data, domain, consumer_key,
             auth_url = 'https://{domain}.salesforce.com/services/oauth2/' \
                        'authorize?response_type=code&client_id=' \
                        '{consumer_key}&redirect_uri=<approved URI>'.format(
-                domain=domain,
-                consumer_key=consumer_key
-                )
+                            domain=domain,
+                            consumer_key=consumer_key
+                        )
             warnings.warn("""
     If your connected app policy is set to "All users may
     self-authorize", you may need to authorize this
